pub struct Multicall3Instance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A Multicall3 instance.
Contains type-safe methods for interacting with an on-chain instance of the
Multicall3 contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
Sourceimpl<P: Provider<N>, N: Network> Multicall3Instance<P, N>
Instantiation and getters/setters.
impl<P: Provider<N>, N: Network> Multicall3Instance<P, N>
Instantiation and getters/setters.
Sourcepub const fn new(address: Address, __provider: P) -> Self
pub const fn new(address: Address, __provider: P) -> Self
Creates a new wrapper around an on-chain Multicall3 contract instance.
See the wrapper’s documentation for more details.
Sourcepub async fn deploy(__provider: P) -> Result<Multicall3Instance<P, N>>
pub async fn deploy(__provider: P) -> Result<Multicall3Instance<P, N>>
Deploys this contract using the given provider and constructor arguments, if any.
Returns a new instance of the contract, if the deployment was successful.
For more fine-grained control over the deployment process, use deploy_builder instead.
Sourcepub fn deploy_builder(__provider: P) -> RawCallBuilder<P, N>
pub fn deploy_builder(__provider: P) -> RawCallBuilder<P, N>
Creates a RawCallBuilder for deploying this contract using the given provider
and constructor arguments, if any.
This is a simple wrapper around creating a RawCallBuilder with the data set to
the bytecode concatenated with the constructor’s ABI-encoded arguments.
Sourcepub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
Sourceimpl<P: Clone, N> Multicall3Instance<&P, N>
impl<P: Clone, N> Multicall3Instance<&P, N>
Sourcepub fn with_cloned_provider(self) -> Multicall3Instance<P, N>
pub fn with_cloned_provider(self) -> Multicall3Instance<P, N>
Clones the provider and returns a new instance with the cloned provider.
Sourceimpl<P: Provider<N>, N: Network> Multicall3Instance<P, N>
Function calls.
impl<P: Provider<N>, N: Network> Multicall3Instance<P, N>
Function calls.
Sourcepub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
pub fn call_builder<C: SolCall>(&self, call: &C) -> SolCallBuilder<&P, C, N>
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
Sourcepub fn aggregate(
&self,
calls: Vec<<Call as SolType>::RustType>,
) -> SolCallBuilder<&P, aggregateCall, N>
pub fn aggregate( &self, calls: Vec<<Call as SolType>::RustType>, ) -> SolCallBuilder<&P, aggregateCall, N>
Creates a new call builder for the [aggregate] function.
Sourcepub fn aggregate3(
&self,
calls: Vec<<Call3 as SolType>::RustType>,
) -> SolCallBuilder<&P, aggregate3Call, N>
pub fn aggregate3( &self, calls: Vec<<Call3 as SolType>::RustType>, ) -> SolCallBuilder<&P, aggregate3Call, N>
Creates a new call builder for the [aggregate3] function.
Sourcepub fn aggregate3Value(
&self,
calls: Vec<<Call3Value as SolType>::RustType>,
) -> SolCallBuilder<&P, aggregate3ValueCall, N>
pub fn aggregate3Value( &self, calls: Vec<<Call3Value as SolType>::RustType>, ) -> SolCallBuilder<&P, aggregate3ValueCall, N>
Creates a new call builder for the [aggregate3Value] function.
Sourcepub fn blockAndAggregate(
&self,
calls: Vec<<Call as SolType>::RustType>,
) -> SolCallBuilder<&P, blockAndAggregateCall, N>
pub fn blockAndAggregate( &self, calls: Vec<<Call as SolType>::RustType>, ) -> SolCallBuilder<&P, blockAndAggregateCall, N>
Creates a new call builder for the [blockAndAggregate] function.
Sourcepub fn getBasefee(&self) -> SolCallBuilder<&P, getBasefeeCall, N>
pub fn getBasefee(&self) -> SolCallBuilder<&P, getBasefeeCall, N>
Creates a new call builder for the [getBasefee] function.
Sourcepub fn getBlockHash(
&self,
blockNumber: U256,
) -> SolCallBuilder<&P, getBlockHashCall, N>
pub fn getBlockHash( &self, blockNumber: U256, ) -> SolCallBuilder<&P, getBlockHashCall, N>
Creates a new call builder for the [getBlockHash] function.
Sourcepub fn getBlockNumber(&self) -> SolCallBuilder<&P, getBlockNumberCall, N>
pub fn getBlockNumber(&self) -> SolCallBuilder<&P, getBlockNumberCall, N>
Creates a new call builder for the [getBlockNumber] function.
Sourcepub fn getChainId(&self) -> SolCallBuilder<&P, getChainIdCall, N>
pub fn getChainId(&self) -> SolCallBuilder<&P, getChainIdCall, N>
Creates a new call builder for the [getChainId] function.
Sourcepub fn getCurrentBlockCoinbase(
&self,
) -> SolCallBuilder<&P, getCurrentBlockCoinbaseCall, N>
pub fn getCurrentBlockCoinbase( &self, ) -> SolCallBuilder<&P, getCurrentBlockCoinbaseCall, N>
Creates a new call builder for the [getCurrentBlockCoinbase] function.
Sourcepub fn getCurrentBlockDifficulty(
&self,
) -> SolCallBuilder<&P, getCurrentBlockDifficultyCall, N>
pub fn getCurrentBlockDifficulty( &self, ) -> SolCallBuilder<&P, getCurrentBlockDifficultyCall, N>
Creates a new call builder for the [getCurrentBlockDifficulty] function.
Sourcepub fn getCurrentBlockGasLimit(
&self,
) -> SolCallBuilder<&P, getCurrentBlockGasLimitCall, N>
pub fn getCurrentBlockGasLimit( &self, ) -> SolCallBuilder<&P, getCurrentBlockGasLimitCall, N>
Creates a new call builder for the [getCurrentBlockGasLimit] function.
Sourcepub fn getCurrentBlockTimestamp(
&self,
) -> SolCallBuilder<&P, getCurrentBlockTimestampCall, N>
pub fn getCurrentBlockTimestamp( &self, ) -> SolCallBuilder<&P, getCurrentBlockTimestampCall, N>
Creates a new call builder for the [getCurrentBlockTimestamp] function.
Sourcepub fn getEthBalance(
&self,
addr: Address,
) -> SolCallBuilder<&P, getEthBalanceCall, N>
pub fn getEthBalance( &self, addr: Address, ) -> SolCallBuilder<&P, getEthBalanceCall, N>
Creates a new call builder for the [getEthBalance] function.
Sourcepub fn getLastBlockHash(&self) -> SolCallBuilder<&P, getLastBlockHashCall, N>
pub fn getLastBlockHash(&self) -> SolCallBuilder<&P, getLastBlockHashCall, N>
Creates a new call builder for the [getLastBlockHash] function.
Sourcepub fn tryAggregate(
&self,
requireSuccess: bool,
calls: Vec<<Call as SolType>::RustType>,
) -> SolCallBuilder<&P, tryAggregateCall, N>
pub fn tryAggregate( &self, requireSuccess: bool, calls: Vec<<Call as SolType>::RustType>, ) -> SolCallBuilder<&P, tryAggregateCall, N>
Creates a new call builder for the [tryAggregate] function.
Sourcepub fn tryBlockAndAggregate(
&self,
requireSuccess: bool,
calls: Vec<<Call as SolType>::RustType>,
) -> SolCallBuilder<&P, tryBlockAndAggregateCall, N>
pub fn tryBlockAndAggregate( &self, requireSuccess: bool, calls: Vec<<Call as SolType>::RustType>, ) -> SolCallBuilder<&P, tryBlockAndAggregateCall, N>
Creates a new call builder for the [tryBlockAndAggregate] function.
Sourceimpl<P: Provider<N>, N: Network> Multicall3Instance<P, N>
Event filters.
impl<P: Provider<N>, N: Network> Multicall3Instance<P, N>
Event filters.
Sourcepub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
pub fn event_filter<E: SolEvent>(&self) -> Event<&P, E, N>
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.